==> haskell-dns-4.1.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.1.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.1.1-1Qd7Cx8B66M1srLbCFfMxq-dns-internal
key:                  dns-4.1.1-1Qd7Cx8B66M1srLbCFfMxq-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  033ced54259fc82c998d5cd3854b66f6
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-1Qd7Cx8B66M1srLbCFfMxq-dns-internal
depends:
    array-0.5.4.0 async-2.2.5-J9V4nOmLz7f63UCPGEHw4R
    attoparsec-0.14.4-4svHBw0u1Cc40MQ1AjsKLc
    auto-update-0.1.6-Fz4tobbH37fKgk5TCMtvlh base-4.17.2.1
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12
    base64-bytestring-1.2.1.0-LY9UF0mrytX7ReHq71Oo2M
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-1ILAtZHAjAqgINNQwApUo
    containers-0.6.7 cryptonite-0.30-67dPvIGY40OLxFpz61cGyx
    hourglass-0.2.12-Dm8D5wbSTl6H9GLjz3EE8b
    iproute-1.7.15-5EIx0b7JR6f5WZElmDysSe mtl-2.2.2
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    psqueues-0.2.8.1-AlhMphbftnUMkL3axTN78

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.1.1
visibility:           public
id:                   dns-4.1.1-48aq5BnIyTGJCdezZuz8d
key:                  dns-4.1.1-48aq5BnIyTGJCdezZuz8d
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  8e2042c4a03bcd26361e47269c126715
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-48aq5BnIyTGJCdezZuz8d
depends:
    array-0.5.4.0 async-2.2.5-J9V4nOmLz7f63UCPGEHw4R
    attoparsec-0.14.4-4svHBw0u1Cc40MQ1AjsKLc
    auto-update-0.1.6-Fz4tobbH37fKgk5TCMtvlh base-4.17.2.1
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12
    base64-bytestring-1.2.1.0-LY9UF0mrytX7ReHq71Oo2M
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-67dPvIGY40OLxFpz61cGyx
    dns-4.1.1-1Qd7Cx8B66M1srLbCFfMxq-dns-internal
    hourglass-0.2.12-Dm8D5wbSTl6H9GLjz3EE8b
    iproute-1.7.15-5EIx0b7JR6f5WZElmDysSe mtl-2.2.2
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    psqueues-0.2.8.1-AlhMphbftnUMkL3axTN78

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-4.1.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.1.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.1.1-3ONkPV9nEvSDpmFnUStwF3-dns-internal
key:                  dns-4.1.1-3ONkPV9nEvSDpmFnUStwF3-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  2318b7d5d13e1020adeb79af980deea8
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-3ONkPV9nEvSDpmFnUStwF3-dns-internal
depends:
    array-0.5.4.0 async-2.2.5-JsOMVyOozRP6jACwcJZjUc
    attoparsec-0.14.4-BuoYNqKkZ0cK5gzfHXNsJW
    auto-update-0.1.6-L2JE1p7fJFzJdkG3Jzy7RG base-4.17.2.1
    base16-bytestring-1.0.2.0-C3cPjjLt0AO1rbHXbT6P0Z
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JGcld4v8YDLG9iCNMxqnvW
    containers-0.6.7 cryptonite-0.30-7RGQk4m0UZG21KYNtSxwaa
    hourglass-0.2.12-IPQB5hJnTz42dJR0umUcmr
    iproute-1.7.15-DC1DWuYV7Jl1nOPDIRybEO mtl-2.2.2
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    psqueues-0.2.8.1-6QapLrrG7adLpqslJec6Hb

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.1.1
visibility:           public
id:                   dns-4.1.1-SPs7SAHTjVFrmPx8Llpnr
key:                  dns-4.1.1-SPs7SAHTjVFrmPx8Llpnr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  3ea1159be25f1c400e1b583621e74efc
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-SPs7SAHTjVFrmPx8Llpnr
depends:
    array-0.5.4.0 async-2.2.5-JsOMVyOozRP6jACwcJZjUc
    attoparsec-0.14.4-BuoYNqKkZ0cK5gzfHXNsJW
    auto-update-0.1.6-L2JE1p7fJFzJdkG3Jzy7RG base-4.17.2.1
    base16-bytestring-1.0.2.0-C3cPjjLt0AO1rbHXbT6P0Z
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-7RGQk4m0UZG21KYNtSxwaa
    dns-4.1.1-3ONkPV9nEvSDpmFnUStwF3-dns-internal
    hourglass-0.2.12-IPQB5hJnTz42dJR0umUcmr
    iproute-1.7.15-DC1DWuYV7Jl1nOPDIRybEO mtl-2.2.2
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    psqueues-0.2.8.1-6QapLrrG7adLpqslJec6Hb

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
